@@ -1,10 +1,10 @@
 package App::pause;
 
-our $DATE = '2015-03-25'; # DATE
-our $VERSION = '0.15'; # VERSION
+our $DATE = '2015-04-01'; # DATE
+our $VERSION = '0.16'; # VERSION
 
 1;
-# ABSTRACT: An API for PAUSE
+# ABSTRACT: A CLI for PAUSE
 
 __END__
 
@@ -14,38 +14,35 @@ __END__
 
 =head1 NAME
 
-App::pause - An API for PAUSE
+App::pause - A CLI for PAUSE
 
 =head1 VERSION
 
-This document describes version 0.15 of App::pause (from Perl distribution WWW-PAUSE-Simple), released on 2015-03-25.
+This document describes version 0.16 of App::pause (from Perl distribution WWW-PAUSE-Simple), released on 2015-04-01.
 
 =head1 DESCRIPTION
 
 This module is just an empty one to ease installation of this distribution (e.g.
 C<< cpanm -n App::pause >>). The real implementation is in
-L<WWW::PAUSE::Simple>.
+L<WWW::PAUSE::Simple>. The CLI is L<pause>.
 
 =head1 SEE ALSO
 
 L<WWW::PAUSE::Simple>
 
+L<pause>
+
 =head1 HOMEPAGE
 
-Please visit the project's homepage at L<https://metacpan.org/release/WWW-PAUSE-Simple>.
+Please visit the project's homepage at L<https://metacpan.org/release/WWW-PAUSE-Simple>.=head1 SOURCE
 
-=head1 SOURCE
-
-Source repository is at L<https://github.com/perlancar/perl-WWW-PAUSE-Simple>.
-
-=head1 BUGS
+Source repository is at L<https://github.com/perlancar/perl-WWW-PAUSE-Simple>.=head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=WWW-PAUSE-Simple>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
